import request from '/@/utils/request';
import { baseUrlHost } from '../baseUrlHost';

/**
 * （不建议写成 request.post(xxx)，因为这样 post 时，无法 params 与 data 同时传参）
 * 注意在写get请求时，参数是params，而不是data，要标注好
 * 
 * 登录api接口集合
 * @method getBannerList 分页查询轮播图
 * @method addBanner 添加轮播图
 * @method getBannerDetail 获取轮播图详情
 * @method updateBanner 更新轮播图
 * @method deleteBanner 删除轮播图
 * @method uploadFile 上传轮播图
 */

export function bannerApi() {
	return {
		getBannerList: (params: object) => {
			return request({
				url: baseUrlHost + '/cpBanner',
				method: 'get',
				params,
			});
		},
		addBanner: (data: object) => {
			return request({
				url: baseUrlHost + '/cpBanner',
				method: 'post',
				data,
			});
		},
		getBannerDetail: (id: Number) => {
			return request({
				url: baseUrlHost + `/cpBanner/${id}`,
				method: 'get',
			});
		},
		updateBanner: (data: object) => {
			return request({
				url: baseUrlHost + '/cpBanner',
				method: 'put',
				data,
			})
		},
		deleteBanner: (id: Number) => {
			return request({
				url: baseUrlHost + `/cpBanner/${id}`,
				method: 'delete',
			});
		},
		uploadFile: (data: object) => {
			return request({
				url: baseUrlHost + '/enAttachment/upload',
				method: 'post',
				data,
				headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
			})
		}
	};
}
