import request from '/@/utils/request';
import { pixelUrlHost } from '/@/api/baseUrlHost';

/**
 * （不建议写成 request.post(xxx)，因为这样 post 时，无法 params 与 data 同时传参）
 * 注意在写get请求时，参数是params，而不是data，要标注好
 * 
 * 登录api接口集合
 * @method getApplyList 获取全部应用
 * @method getServicesList 获取应用服务列表
 * @method getApplyDetail 获取应用服务详情
 * @method saveApply 添加应用服务
 * @method updateApply 更新应用服务
 * @method deleteApply 删除应用服务
 */

export function applyApi() {
	return {
		getAllServices: () => {
			return request({
				url: pixelUrlHost + '/paServices/all',
				method: 'get',
			});
		},
		getServicesList: (params: object) => {
			return request({
				url: pixelUrlHost + '/paServices',
				method: 'get',
				params,
			});
		},
		getApplyDetail: (id: Number) => {
			return request({
				url: pixelUrlHost + `/paServices/${id}`,
				method: 'get',
			});
		},
		saveApply: (data: object) => {
			return request({
				url: pixelUrlHost + '/paServices',
				method: 'post',
				data,
			})
		},
		updateApply: (data: object) => {
			return request({
				url: pixelUrlHost + '/paServices',
				method: 'put',
				data,
			})
		},
		deleteApply: (id: Number) => {
			return request({
				url: pixelUrlHost + `/paServices/${id}`,
				method: 'delete',
			});
		},
	};
}
