import request from '/@/utils/request';
import { baseUrlHost } from '../baseUrlHost';

/**
 * （不建议写成 request.post(xxx)，因为这样 post 时，无法 params 与 data 同时传参）
 * 注意在写get请求时，参数是params，而不是data，要标注好
 * 
 * 登录api接口集合
 * @method getUserList 获取分页用户列表
 * @method deleteUser 删除用户
 * @method addUser 保存用户
 * @method updateUser 更新用户
 * @method getuserListAll 获取全部用户
 * @method getUserDetail 查询单个用户
 * @method updatepwd 修改用户密码
 */

export function userApi() {
  return {
    getUserList: (params:object) => {
      return request({
        url: baseUrlHost + '/acUser',
        method: 'get',
        params,
      });
    },
    addUser:(data:object) => {
      return request({
        url:baseUrlHost + '/acUser',
        method:'post',
        data,
      })
    },
    updateUser: (data: object) => {
      return request({
        url: baseUrlHost + '/acUser',
        method: 'put',
        data,
      })
    },
    getUserDetail: (id: Number) => {
      return request({
        url: baseUrlHost + `/acUser/${id}`,
        method: 'get',
      });
    },
    deleteUser: (id: Number) => {
      return request({
        url: baseUrlHost + `/acUser/${id}`,
        method: 'delete',
      });
    },
    getuserListAll: () => {
      return request({
        url: baseUrlHost + `/acUser/all`,
        method: 'get',
      });
    },
    updatepwd: (id:Number,data:object) => {
      return request({
        url: baseUrlHost + `/acUser/${id}/pwdreset`,
        method: 'post',
        data
      })
    }
  };
}
