import request from '/@/utils/request';
import { baseUrlHost } from '../baseUrlHost';

/**
 * （不建议写成 request.post(xxx)，因为这样 post 时，无法 params 与 data 同时传参）
 * 注意在写get请求时，参数是params，而不是data，要标注好
 * 
 * 登录api接口集合
 * @method getVideoList 分页查询视频
 * @method deleteVideo 删除视频
 * @method getVideoDetail 获取视频详情
 * @method saveVideo 保存视频
 * @method updateVideo 更新视频
 */

export function videoApi() {
	return {
		getVideoList: (params: object) => {
			return request({
				url: baseUrlHost + '/cpVideo',
				method: 'get',
				params,
			});
		},
		deleteVideo: (id: Number) => {
			return request({
				url: baseUrlHost + `/cpVideo/${id}`,
				method: 'delete',
			});
		},
		getVideoDetail: (id: Number) => {
			return request({
				url: baseUrlHost + `/cpVideo/${id}`,
				method: 'get',
			});
		},
		saveVideo: (data: object) => {
			return request({
				url: baseUrlHost + '/cpVideo',
				method: 'post',
				data,
			})
		},
		updateVideo: (data: object) => {
			return request({
				url: baseUrlHost + '/cpVideo',
				method: 'put',
				data,
			})
		},
		uploadFileType: (data: object) => {
			return request({
				url: baseUrlHost + '/enAttachment/uploadByType',
				method: 'post',
				data,
				headers: { 'Content-Type': 'multipart/form-data'}
			})
		}
	};
}
