import vue from '@vitejs/plugin-vue';
import { resolve } from 'path';
import { defineConfig, loadEnv, ConfigEnv } from 'vite';
import vueSetupExtend from 'vite-plugin-vue-setup-extend-plus';
import viteCompression from 'vite-plugin-compression';
import { buildConfig } from './src/utils/build';
import { codeInspectorPlugin } from 'code-inspector-plugin';

const pathResolve = (dir: string) => {
	return resolve(__dirname, '.', dir);
};

const alias: Record<string, string> = {
	'/@': pathResolve('./src/'),
	'vue-i18n': 'vue-i18n/dist/vue-i18n.cjs.js',
};

// 请求映射后端路径
const url:string = 'http://8.138.171.103';

const viteConfig = defineConfig((mode: ConfigEnv) => {
	const env = loadEnv(mode.mode, process.cwd());
	
	return {
		plugins: [vue(), vueSetupExtend(), viteCompression(), JSON.parse(env.VITE_OPEN_CDN) ? buildConfig.cdn() : null, codeInspectorPlugin({bundler: 'vite'})],
		root: process.cwd(),
		resolve: { alias },
		base: mode.command === 'serve' ? './' : env.VITE_PUBLIC_PATH,
		optimizeDeps: { exclude: ['vue-demi'] },
		server: {
			host: '0.0.0.0',
			port: env.VITE_PORT as unknown as number,
			open: JSON.parse(env.VITE_OPEN),
			hmr: true,
			proxy: {
				'/vueAdminApi': {
					target: url+':8081',
					// target: 'http://8.138.175.106:8090',
					// target: 'https://www.ymsc.org.cn/vueAdminApi',
					ws: true,
					secure: false,
					changeOrigin: true,
					rewrite: (path) => path.replace(/^\/vueAdminApi/, ''),
				},
				'/pixelApi': {
					target: url+'/pixelApi',
					ws: true,
					secure: false,
					changeOrigin: true,
					rewrite: (path) => path.replace(/^\/pixelApi/, ''),
				},
				'/vueAdmin': {
					target: 'http://localhost:8888',
					// target: 'http://8.138.175.106:8090',
					// target: 'https://www.ymsc.org.cn/vueAdmin',
					ws: true,
					secure: false,
					changeOrigin: true,
					rewrite: (path) => path.replace(/^\/vueAdmin/, ''),
				},
				'/upload': {
					target: url,
					// target: 'http://8.138.175.106',
					// target: 'https://www.ymsc.org.cn/upload',
					secure: false,
					ws: true,
					changeOrigin: true,
				},
				'/aiupload': {
					target: url,
					// target: 'http://8.138.175.106',
					// target: 'https://www.ymsc.org.cn/upload',
					secure: false,
					ws: true,
					changeOrigin: true,
				},
				'/static': {
					target: url,
					secure: false,
					ws: true,
					changeOrigin: true,
				},
				'/gitee': {
					target: 'https://gitee.com',
					ws: true,
					changeOrigin: true,
					rewrite: (path) => path.replace(/^\/gitee/, ''),
				},
			},
		},
		build: {
			outDir: 'dist',
			chunkSizeWarningLimit: 1500,
			rollupOptions: {
				output: {
					chunkFileNames: 'assets/js/[name]-[hash].js',
					entryFileNames: 'assets/js/[name]-[hash].js',
					assetFileNames: 'assets/[ext]/[name]-[hash].[ext]',
					manualChunks(id) {
						if (id.includes('node_modules')) {
							return id.toString().match(/\/node_modules\/(?!.pnpm)(?<moduleName>[^\/]*)\//)?.groups!.moduleName ?? 'vender';
						}
					},
				},
				...(JSON.parse(env.VITE_OPEN_CDN) ? { external: buildConfig.external } : {}),
			},
		},
		css: { preprocessorOptions: { css: { charset: false } } },
		define: {
			__VUE_I18N_LEGACY_API__: JSON.stringify(false),
			__VUE_I18N_FULL_INSTALL__: JSON.stringify(false),
			__INTLIFY_PROD_DEVTOOLS__: JSON.stringify(false),
			__NEXT_VERSION__: JSON.stringify(process.env.npm_package_version),
			__NEXT_NAME__: JSON.stringify(process.env.npm_package_name),
		},
	};
});

export default viteConfig;
